import { __decorate } from 'tslib';
import { Component, ChangeDetectionStrategy, forwardRef, ChangeDetectorRef, Input, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { InputBoolean } from 'ng-element-ui/core/utils';

class NelInputNumberComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.displayValue = 0;
        this.decreaseDisabled = false;
        this.increaseDisabled = false;
        this.nelStep = 1;
        this.nelDisabled = false;
        this.change = (value) => { };
    }
    onModelChange(event) {
        this.rangeDisabled(event);
    }
    blur() {
        const checkStr = `^-?\\d*(\\.?\\d+)`;
        const checkRegExp = new RegExp(checkStr, 'g');
        if (this.displayValue) {
            const formatter = this.inputEle.nativeElement.value.match(checkRegExp);
            if (formatter) {
                this.displayValue = formatter[0];
                this.inputEle.nativeElement.value = formatter[0];
            }
        }
    }
    decrease() {
        if (!this.nelDisabled && !this.decreaseDisabled) {
            this.rangeDisabled(parseFloat(this.displayValue.toString()) - this.nelStep);
        }
    }
    increase() {
        if (!this.nelDisabled && !this.increaseDisabled) {
            this.rangeDisabled(parseFloat(this.displayValue.toString()) + this.nelStep);
        }
    }
    rangeDisabled(val) {
        console.log(val);
        console.log(this.nelMin);
        if (this.nelMin && val <= this.nelMin) {
            this.displayValue = this.nelMin;
            this.decreaseDisabled = true;
        }
        else {
            this.displayValue = val;
            this.decreaseDisabled = false;
        }
        if (this.nelMax && val >= this.nelMax) {
            this.displayValue = this.nelMax;
            this.increaseDisabled = true;
        }
        else {
            this.displayValue = val;
            this.increaseDisabled = false;
        }
        if (this.inputEle) {
            this.inputEle.nativeElement.value = this.displayValue;
        }
        this.cdr.markForCheck();
    }
    writeValue(val) {
        this.rangeDisabled(val);
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelInputNumberComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-input-number',
                template: "<div class=\"el-input-number\" [class.is-disabled]=\"nelDisabled\">\r\n  <span (click)=\"decrease()\" class=\"el-input-number__decrease\" [class.is-disabled]=\"decreaseDisabled\" role=\"button\">\r\n    <i class=\"el-icon-minus\"></i>\r\n  </span>\r\n  <span (click)=\"increase()\" class=\"el-input-number__increase\" [class.is-disabled]=\"increaseDisabled\" role=\"button\">\r\n    <i class=\"el-icon-plus\"></i>\r\n  </span>\r\n  <div class=\"el-input\" [class.is-disabled]=\"nelDisabled\">\r\n    <input #inputEle class=\"el-input__inner\" max=\"10\" min=\"1\" type=\"text\" autocomplete=\"off\" role=\"spinbutton\"\r\n      [ngModel]=\"displayValue\" (ngModelChange)=\"onModelChange($event)\" (blur)=\"blur()\">\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelInputNumberComponent),
                        multi: true
                    }
                ]
            },] }
];
NelInputNumberComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
NelInputNumberComponent.propDecorators = {
    nelMin: [{ type: Input }],
    nelMax: [{ type: Input }],
    nelStep: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    inputEle: [{ type: ViewChild, args: ['inputEle', { static: false },] }]
};
__decorate([
    InputBoolean()
], NelInputNumberComponent.prototype, "nelDisabled", void 0);

class NelInputNumberModule {
}
NelInputNumberModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelInputNumberComponent
                ],
                exports: [
                    NelInputNumberComponent
                ],
                imports: [
                    FormsModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelInputNumberComponent, NelInputNumberModule };
//# sourceMappingURL=ng-element-ui-input-number.js.map
