import { __decorate } from 'tslib';
import { EventEmitter, Component, ChangeDetectionStrategy, forwardRef, ChangeDetectorRef, Input, Output, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';

class NelInputComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this.nelPlaceHolder = '';
        this.nelDisabled = false;
        this.nelClearable = false;
        this.nelShowPassword = false;
        this.nelSize = null;
        this.onClear = new EventEmitter();
        this.focused = false;
        this.hovering = false;
        this.type = 'text';
        this.change = (val) => { };
    }
    ngOnChanges(changes) {
        const { nelShowPassword } = changes;
        if (nelShowPassword) {
            this.type = this.nelShowPassword ? 'password' : 'text';
        }
    }
    onInput($event) {
        this.data = $event.target.value;
        this.change(this.data);
    }
    handleBlur() {
        this.focused = false;
    }
    handleFocus() {
        this.focused = true;
    }
    handleClear() {
        this.data = '';
        this.change(this.data);
        this.inputEle.nativeElement.value = this.data;
        this.onClear.emit();
    }
    handleMouseEnter() {
        this.hovering = true;
    }
    handleMouseLeave() {
        this.hovering = false;
    }
    changeType() {
        this.type = this.type === 'text' ? 'password' : 'text';
    }
    writeValue(value) {
        this.data = value;
        this.cdr.detectChanges();
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-input',
                template: "<input #inputEle class=\"el-input__inner\" [type]=\"type\" autocomplete=\"off\" [value]=\"data\" [placeholder]=\"nelPlaceHolder\"\r\n  [disabled]=\"nelDisabled\" (input)=\"onInput($event)\" (blur)=\"handleBlur()\" (focus)=\"handleFocus()\">\r\n<span *ngIf=\"nelClearable && data?.length > 0 && (focused || hovering)\" class=\"el-input__suffix\"\r\n  (click)=\"handleClear()\">\r\n  <span class=\"el-input__suffix-inner\">\r\n    <i class=\"el-input__icon el-icon-circle-close el-input__clear\"></i>\r\n  </span>\r\n</span>\r\n<span *ngIf=\"nelShowPassword && (data?.length > 0 || focused || hovering)\" class=\"el-input__suffix\"\r\n  (click)=\"changeType()\">\r\n  <span class=\"el-input__suffix-inner\">\r\n    <i class=\"el-input__icon el-icon-view el-input__clear\"></i>\r\n  </span>\r\n</span>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelInputComponent),
                        multi: true
                    }
                ],
                host: {
                    class: 'el-input',
                    '[class.is-disabled]': 'nelDisabled',
                    '[class.el-input--suffix]': 'nelClearable',
                    '[class.el-input--medium]': `nelSize == 'medium'`,
                    '[class.el-input--small]': `nelSize == 'small'`,
                    '[class.el-input--mini]': `nelSize == 'mini'`,
                    '(mouseenter)': 'handleMouseEnter()',
                    '(mouseleave)': 'handleMouseLeave()'
                }
            },] }
];
NelInputComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
NelInputComponent.propDecorators = {
    nelPlaceHolder: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    nelClearable: [{ type: Input }],
    nelShowPassword: [{ type: Input }],
    nelSize: [{ type: Input }],
    onClear: [{ type: Output }],
    inputEle: [{ type: ViewChild, args: ['inputEle', { static: false },] }]
};
__decorate([
    InputBoolean()
], NelInputComponent.prototype, "nelDisabled", void 0);
__decorate([
    InputBoolean()
], NelInputComponent.prototype, "nelClearable", void 0);
__decorate([
    InputBoolean()
], NelInputComponent.prototype, "nelShowPassword", void 0);

class NelInputModule {
}
NelInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelInputComponent
                ],
                exports: [
                    NelInputComponent
                ],
                imports: [
                    CommonModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelInputComponent, NelInputModule };
//# sourceMappingURL=ng-element-ui-input.js.map
