import { Component, ChangeDetectionStrategy, forwardRef, Input, EventEmitter, Output, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

class NelRateComponent {
    constructor() {
        this.nelColors = ['#F7BA2A', '#F7BA2A', '#F7BA2A'];
        this.data = null;
        this.currentValue = -1;
        this.starArray = [0, 1, 2, 3, 4];
        this.change = (val) => { };
    }
    handleHover(value) {
        this.currentValue = value;
    }
    handleClick(value) {
        this.data = value;
    }
    writeValue(val) {
        this.data = val;
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelRateComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-rate',
                template: "<div class=\"el-rate\" role=\"slider\" aria-valuetext=\"\" aria-valuemin=\"0\" aria-valuemax=\"5\" tabindex=\"0\" aria-valuenow=\"0\">\r\n  <nel-rate-item *ngFor=\"let item of starArray; let index=index\" [data]=\"index\" [currentValue]=\"currentValue\"\r\n    [value]=\"data\" [colors]=\"nelColors\" (onHover)=\"handleHover($event)\" (onClick)=\"handleClick($event)\"></nel-rate-item>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelRateComponent),
                        multi: true
                    }
                ]
            },] }
];
NelRateComponent.propDecorators = {
    nelColors: [{ type: Input }]
};

class NelRateItemComponent {
    constructor() {
        // 鼠标当前move的下标
        this.currentValue = -1;
        // 当前选择的评分
        this.value = null;
        this.data = 0;
        this.onHover = new EventEmitter();
        this.onClick = new EventEmitter();
    }
    handleMouseover() {
        this.onHover.emit(this.data);
    }
    handleMouseleave() {
        this.onHover.emit(-1);
    }
    handleClick() {
        this.onClick.emit(this.data);
    }
    getOn() {
        return this.data <= this.currentValue
            || (this.currentValue === -1 && this.value !== null && this.data <= this.value);
    }
    getHover() {
        return this.data <= this.currentValue;
    }
    getColor() {
        const value = this.currentValue !== -1 ? this.currentValue : this.value ? this.value : -1;
        let color = 'rgb(198, 209, 222)';
        const colorItem = this.color.find(item => value <= item.key);
        if (colorItem) {
            color = colorItem.value;
        }
        return this.getOn() ? color : 'rgb(198, 209, 222)';
    }
    ngOnChanges(changes) {
        const { colors } = changes;
        if (colors) {
            let colorList = [];
            if (colors instanceof Array) {
                colorList = [
                    { key: 2, value: '#F7BA2A' },
                    { key: 4, value: '#F7BA2A' },
                    { key: 5, value: '#F7BA2A' },
                ];
            }
            else {
                for (const key in colors.currentValue) {
                    colorList.push({
                        key: Number(key),
                        value: colors.currentValue[key]
                    });
                }
            }
            colorList.sort((a, b) => {
                return a.key - b.key;
            });
            this.color = colorList;
        }
    }
}
NelRateItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-rate-item',
                template: "<span class=\"el-rate__item\" style=\"cursor: pointer;\" (mouseover)=\"handleMouseover()\" (mouseleave)=\"handleMouseleave()\"\r\n  (click)=\"handleClick()\">\r\n  <i class=\"el-rate__icon\" [class.el-icon-star-off]=\"!getOn()\" [class.el-icon-star-on]=\"getOn()\"\r\n    [class.hover]=\"getHover()\" [style.color]=\"getOn() ? 'rgb(247, 186, 42)' : 'rgb(198, 209, 222)'\"></i>\r\n</span>\r\n"
            },] }
];
NelRateItemComponent.propDecorators = {
    currentValue: [{ type: Input }],
    value: [{ type: Input }],
    data: [{ type: Input }],
    colors: [{ type: Input }],
    onHover: [{ type: Output }],
    onClick: [{ type: Output }]
};

class NelRateModule {
}
NelRateModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelRateComponent,
                    NelRateItemComponent
                ],
                exports: [
                    NelRateComponent,
                    NelRateItemComponent
                ],
                imports: [
                    CommonModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelRateComponent, NelRateModule, NelRateItemComponent as ɵa };
//# sourceMappingURL=ng-element-ui-rate.js.map
